@@ -21,6 +21,12 @@ vandal.toolkit is a set of data manipulation tools that can be directly accessed
 
         auto_sort(data, split_method, trigger = lambda x: x[0]) - automatically splits all values in a list and sorts them based on the added trigger as lambda x: [x[i], x[i]] and joins them back together.
 
+	create_password(length) - creates a random password with adjustable lenght (default: length = 8).
+
+        save_to(file, prefix, func_name, choice) - file saver for code clarity.
+
+        file_handler(file) - handles the file extenstion upon import.
+	
 '''
 
 # metadata of the used library.
@@ -111,8 +117,55 @@ def auto_sort(data, split_method, trigger = lambda x: x[0]):
                 merged_final += ['-'.join(i)]
         return merged_final
 
-# creates a random password with adjustable lenght (default: lenght = 8).
-def create_password(lenght = 8):
+# creates a random password with adjustable lenght (default: length = 8).
+def create_password(length = 8):
         import random
         particles = 'abcdefghijklmnoprstuxwyzqABCDEFGHIJKLMNOPRSTUXWYZQ0123456789'
-        return ''.join(random.sample(particles, lenght))
\ No newline at end of file
+        return ''.join(random.sample(particles, length))
+
+# handles the file extenstion upon import.
+def file_handler(file):
+        import pandas as pd
+        file = file.replace("'", '"').strip('"')
+        if str(file).endswith('.csv'):
+            data = pd.read_csv(file)
+            print('AVAILABLE COLUMNS: ')
+            for col in data.columns:
+                print(col)
+        elif str(file).endswith('.xlsx'):
+            data = pd.read_excel(file)
+            print('AVAILABLE COLUMNS: ')
+            for col in data.columns:
+                print(col)
+        elif str(file).endswith('.json'):
+            data = pd.read_json(file)
+            print('AVAILABLE COLUMNS: ')
+            for col in data.columns:
+                print(col)
+        else:
+            raise Exception('=== ONLY CSV, XLSX AND JSON FILES SUPPORTED. ===\n')
+        file_col = input('\nEnter column name: ').replace("'", '"').strip('"')
+        try:
+            data = data[file_col]
+            return data
+        except:
+            raise Exception('=== INVALID COLUMN NAME. ===\n')
+
+# file saver for code clarity.
+def save_to(file, prefix, func_name, choice):
+        import pandas as pd
+        import os
+        if choice == '1' or choice == 'csv':
+                extension = '.csv'
+                file.to_csv(prefix + func_name + extension)
+                print(os.path.join(os.getcwd() + '\\' + prefix + func_name + extension))
+        elif choice == '2' or choice == 'xlsx':
+                extension = '.xlsx'
+                file.to_excel(prefix + func_name + extension)
+                print(os.path.join(os.getcwd() + '\\' + prefix + func_name + extension))
+        elif choice == '3' or choice == 'json':
+                extension = '.json'
+                file.to_json(prefix + func_name + extension)
+                print(os.path.join(os.getcwd() + '\\' + prefix + func_name + extension))
+        else:
+                print('=== NO OPTION CHOSEN, EXITING THE MENU... =\n')
