@@ -29,15 +29,6 @@ class Dijkstra:
             origin - origin node as a starting point.
             destination - destination node of the desired route.
 
-    (DEVELOPER MODE)
-    ----------------
-
-    Developer mode functions can only be set up manually by removing the '#DEVELOPER MODE -' in the source code.
-
-        * takes no additional arguments.
-        * Requirements:
-            '# DEVELOPER MODE -' removed in the code.
-
     '''
 
     # metadata of the used library.
@@ -52,21 +43,18 @@ class Dijkstra:
         __donate__,
     )
 
-    # initial value configuration.
+    # initial launch.
     def __init__(self):
         pass
 
-    # DEVELOPER MODE - @classLog('__str__()')
     # class information.
     def __str__(self):
         return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
 
-    # DEVELOPER MODE - @classLog('__repr__()')
     # class information.
     def __repr__(self):
         return f'Dijkstra defining object that stores the configuration data for finding the path within {self.nodes} from {self.origin} => {self.destination}.'
 
-    # DEVELOPER MODE - @classLog('execute() - built in function.')
     # executes a Dijkstra algorithm route scan on a defined path.
     def execute(self, nodes, origin, destination, log_summary = False):
         self.nodes = nodes
