@@ -51,15 +51,6 @@ class MonteCarlo:
                 method - default method is Basic histogram and it's performed by automation. In order to plot Empirical rule histogram add method = 'e' as the last argument. - NOTE: method of a histogram must be placed within quotation marks.
             * automatically executes the .get_stats(filtered = True) function in order to get standard deviation for the Empirical rule plotting.
 
-    (DEVELOPER MODE)
-    ----------------
-
-    Developer mode functions can only be set up manually by removing the '#DEVELOPER MODE -' in the source code.
-
-        * takes no additional arguments.
-        * Requirements:
-            '# DEVELOPER MODE -' removed in the code.
-
     '''
 
     # metadata of the used library.
@@ -74,30 +65,19 @@ class MonteCarlo:
         __donate__,
     )
 
-    # import duality package decorators.
-    # DEVELOPER MODE -  from duality import track, record
-
     # initial launch.
-    # DEVELOPER MODE - @track.entry('init')
-    # DEVELOPER MODE - @record.entry(option_name = 'init', option_description = 'initial launch.')
     def __init__(self):
         pass
 
     # class information.
-    # DEVELOPER MODE - @track.entry('string')
-    # DEVELOPER MODE - @record.entry(option_name = 'string', option_description = 'class information.')
     def __str__(self):
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
     # class information.
-    # DEVELOPER MODE - @track.entry('representation')
-    # DEVELOPER MODE - @record.entry(option_name = 'repr', option_description = 'shows object details.')
     def __repr__(self):
         return f'Monte Carlo defining object that stores the configuration data for creating {self.num_sims} simulations in a period of {self.time_seq} time measurement units.'
 
     # executes a Monte Carlo simulation on a defined data set.
-    # DEVELOPER MODE - @track.entry('execution')
-    # DEVELOPER MODE - @record.entry(option_name = 'execution', option_description = 'executes a Monte Carlo simulation on a defined data set.')
     def execute(self, list_of_values, time_seq, num_sims, ref_value_index = 0):
         self.list_of_values = list_of_values
         self.time_seq = time_seq
@@ -146,14 +126,10 @@ class MonteCarlo:
         return data
 
     # shows the percentage of Monte Carlo simulation value change for every iteration.
-    # DEVELOPER MODE - @track.entry('change')
-    # DEVELOPER MODE - @record.entry(option_name = 'change', option_description = 'shows the percentage of Monte Carlo simulation value change for every iteration.')
     def get_change(self):
         return self.results.pct_change()
 
     # calculates the risk of negative values occuring.
-    # DEVELOPER MODE - @track.entry('risk')
-    # DEVELOPER MODE - @record.entry(option_name = 'risk', option_description = 'calculates the risk of negative values occuring.')
     def get_risk(self, risk_sims = 5000):
         import random
         import pandas as pd
@@ -183,8 +159,6 @@ class MonteCarlo:
         print('\nRisk for this option is', round(NRisk,2), '%.')
 
     # plots the Monte Carlo simulation on a graph.
-    # DEVELOPER MODE - @track.entry('graph')
-    # DEVELOPER MODE - @record.entry(option_name = 'graph', option_description = 'plots the Monte Carlo simulation on a graph.')
     def graph(self, graph_title = 'Monte Carlo simulation', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True):
         print('\nMonteCarlo() plotting initialized.')
         import matplotlib.pyplot as plt
@@ -199,8 +173,6 @@ class MonteCarlo:
         print('MonteCarlo() plotting finished.')
 
     # shows the statistics of the Monte Carlo simulation.
-    # DEVELOPER MODE - @track.entry('statistics')
-    # DEVELOPER MODE - @record.entry(option_name = 'statistics', option_description = 'shows the statistics of the Monte Carlo simulation.')
     def get_stats(self, filtered = False):
         import numpy as np
         mean_value = np.mean(self.results.loc[self.time_seq])
@@ -222,8 +194,6 @@ class MonteCarlo:
             print('Minimum: ', minimum_value, '\n')
 
     # plots the histogram of Monte Carlo simulation.
-    # DEVELOPER MODE - @track.entry('histogram')
-    # DEVELOPER MODE - @record.entry(option_name = 'histogram', option_description = 'plots the histogram of Monte Carlo simulation.')
     def hist(self, graph_title = 'Histogram of value frequencies', x_title = 'X axis', y_title = 'Y axis', plot_size = (25,10), perform_block = True, **method):
         self.get_stats(filtered = True)
         std_plus = self.mean_value + self.standard_deviation
@@ -262,16 +232,118 @@ class MonteCarlo:
         plt.show(block = perform_block)
         print('Histogram plotting finished.')
 
-    # DEVELOPER MODE - @record.display(method = 'dictionary')
-    # DEVELOPER MODE - @track.entry('menu')
-    # DEVELOPER MODE - @record.entry(option_name = 'menu', option_description = 'access saved menu particles from function execution.')
     # access saved menu particles from function execution.  
     def get_menu(self):
         return
 
-    # DEVELOPER MODE - @track.display()
-    # DEVELOPER MODE - @track.entry('logs')
-    # DEVELOPER MODE - @record.entry(option_name = 'logs', option_description = 'access saved logs from function execution.')
     # access saved logs from function execution.
     def get_logs(self):
         return
+
+# CLI application.
+def MCapp():
+    import colorama
+    from colorama import Fore
+    import os
+    from vandal.misc._meta import __version__
+    from vandal.objects import MonteCarlo
+    from vandal.hub.toolkit import (
+        save_to,
+        file_handler,
+    )
+    os.system('cls')
+    # initiates coloring.
+    colorama.init()
+
+    # vandal.App version.
+    __APPversion__ = 'v 1.2.5'
+    
+    # greeting.
+    print(Fore.GREEN + '\n - vandal Command Line Interface Application © David Kundih -', __APPversion__)
+    print(Fore.GREEN + ' - vandal package version -', 'v',__version__, Fore.RESET, '\n')
+    print(Fore.YELLOW + 'How do you wish to input your data?', Fore.RESET)
+    print('0 | Manual input')
+    print('1 | File input\n')
+    inputchoice = input('Enter the option number: ')
+
+    # manual input.
+    if inputchoice == '0':
+        import pandas as pd
+        iter = True
+        print(Fore.RED + 'Write any non-number value to stop.', Fore.RESET)
+        data = []
+
+        while iter:
+            try:
+                listinput = input('Enter a value: ')
+                listinput = listinput.replace(",", ".")
+                listinput = float(listinput)
+                data.append(listinput)
+            except:
+                iter = False
+
+        data = pd.DataFrame(data)
+        data = data[0]
+
+    # file input.
+    elif inputchoice == '1':
+        inputfile = input('Enter the file destination: ')
+        data = file_handler(file = inputfile)
+
+    MC = MonteCarlo()
+    simulations = int(input('Enter number of simulations: ') or 100)
+    period = int(input('Enter desired period: ') or 50)
+    print('')
+    executed = MC.execute(list_of_values = data, num_sims = simulations, time_seq = period)
+
+    # options after defining the parameters. 
+    while True:
+        action = input('\n>>> ACTIONS: graph, change, values, stats, risk, hist, home, help: ')
+        if action == 'graph':
+            title = input('Title: ')
+            x_axis = input('X axis title:')
+            y_axis = input('Y axis title:')
+            MC.graph(graph_title = title, x_title = x_axis, y_title = y_axis)
+        if action == 'change':
+            print('1 | csv')
+            print('2 | xlsx')
+            print('3 | json')
+            file_type = input('\nEnter the number or name of file type: ')
+            output = MC.get_change()
+            try:
+                save_to(file = executed, prefix = 'vandal.MonteCarlo - ' , func_name = 'change', choice = file_type)
+            except:
+                raise Exception('=== UNABLE TO SAVE, PLEASE SELECT ONE OF THE OPTIONS AND/OR RUN THE TERMINAL AS AN ADMINISTRATOR. ===')
+        if action == 'values':
+            print('1 | csv')
+            print('2 | xlsx')
+            print('3 | json')
+            file_type = input('\nEnter the number or name of file type: ')
+            try:
+                save_to(file = executed, prefix = 'vandal.MonteCarlo - ', func_name = 'values', choice = file_type)
+            except:
+                raise Exception('=== UNABLE TO SAVE, PLEASE RUN THE TERMINAL AS AN ADMINISTRATOR. ===')
+        if action == 'stats' or action == 'statistics':
+            MC.get_stats()
+        if action == 'risk':
+            sample = int(input('Number of iterations to measure risk on: ') or 5000)
+            MC.get_risk(risk_sims = sample)
+        if action == 'hist' or action == 'histogram':
+            x_axis = input('X axis title:')
+            y_axis = input('Y axis title:')
+            print('0 | Basic Histogram')
+            print('1 | Empirical Rule Histogram')
+            method = input('\nEnter histogram method: ')
+            if method == '0':
+                MC.hist(x_title = x_axis, y_title = y_axis)
+            elif method == '1':
+                MC.hist(x_title = x_axis, y_title = y_axis, method = 'e')
+            else:
+                print(Fore.RED + '=== INVALID METHOD. ===\n', Fore.RESET)
+        if action == 'home':
+            break
+        if action == 'help':
+            print(Fore.YELLOW + 'https://github.com/dkundih/vandal', Fore.RESET)
+
+if __name__ == '__main__':
+    MCapp()
\ No newline at end of file
